
From: NeilBrown <neilb@cse.unsw.edu.au>

The patch below contains the following cleanups:
- make some needlessly global code static

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Signed-off-by: Neil Brown <neilb@cse.unsw.edu.au>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/fs/nfsd/export.c |   22 +++++++++++-----------
 25-akpm/fs/nfsd/lockd.c  |    2 +-
 25-akpm/fs/nfsd/nfsfh.c  |   11 ++++++-----
 25-akpm/fs/nfsd/nfssvc.c |    2 +-
 25-akpm/fs/nfsd/vfs.c    |    8 ++++----
 5 files changed, 23 insertions(+), 22 deletions(-)

diff -puN fs/nfsd/export.c~nfsd--global-static-cleanups-for-nfsd fs/nfsd/export.c
--- 25/fs/nfsd/export.c~nfsd--global-static-cleanups-for-nfsd	2005-02-07 19:19:14.000000000 -0800
+++ 25-akpm/fs/nfsd/export.c	2005-02-07 19:19:14.000000000 -0800
@@ -79,9 +79,9 @@ void expkey_put(struct cache_head *item,
 	}
 }
 
-void expkey_request(struct cache_detail *cd,
-		    struct cache_head *h,
-		    char **bpp, int *blen)
+static void expkey_request(struct cache_detail *cd,
+			   struct cache_head *h,
+			   char **bpp, int *blen)
 {
 	/* client fsidtype \xfsid */
 	struct svc_expkey *ek = container_of(h, struct svc_expkey, h);
@@ -95,7 +95,7 @@ void expkey_request(struct cache_detail 
 }
 
 static struct svc_expkey *svc_expkey_lookup(struct svc_expkey *, int);
-int expkey_parse(struct cache_detail *cd, char *mesg, int mlen)
+static int expkey_parse(struct cache_detail *cd, char *mesg, int mlen)
 {
 	/* client fsidtype fsid [path] */
 	char *buf;
@@ -284,9 +284,9 @@ void svc_export_put(struct cache_head *i
 	}
 }
 
-void svc_export_request(struct cache_detail *cd,
-			struct cache_head *h,
-			char **bpp, int *blen)
+static void svc_export_request(struct cache_detail *cd,
+			       struct cache_head *h,
+			       char **bpp, int *blen)
 {
 	/*  client path */
 	struct svc_export *exp = container_of(h, struct svc_export, h);
@@ -340,7 +340,7 @@ static int check_export(struct inode *in
 
 }
 
-int svc_export_parse(struct cache_detail *cd, char *mesg, int mlen)
+static int svc_export_parse(struct cache_detail *cd, char *mesg, int mlen)
 {
 	/* client path expiry [flags anonuid anongid fsid] */
 	char *buf;
@@ -510,8 +510,8 @@ exp_find_key(svc_client *clp, int fsid_t
 	return ek;
 }
 
-int exp_set_key(svc_client *clp, int fsid_type, u32 *fsidv, 
-		struct svc_export *exp)
+static int exp_set_key(svc_client *clp, int fsid_type, u32 *fsidv,
+		       struct svc_export *exp)
 {
 	struct svc_expkey key, *ek;
 
@@ -999,7 +999,7 @@ static void e_stop(struct seq_file *m, v
 	exp_readunlock();
 }
 
-struct flags {
+static struct flags {
 	int flag;
 	char *name[2];
 } expflags[] = {
diff -puN fs/nfsd/lockd.c~nfsd--global-static-cleanups-for-nfsd fs/nfsd/lockd.c
--- 25/fs/nfsd/lockd.c~nfsd--global-static-cleanups-for-nfsd	2005-02-07 19:19:14.000000000 -0800
+++ 25-akpm/fs/nfsd/lockd.c	2005-02-07 19:19:14.000000000 -0800
@@ -60,7 +60,7 @@ nlm_fclose(struct file *filp)
 	fput(filp);
 }
 
-struct nlmsvc_binding		nfsd_nlm_ops = {
+static struct nlmsvc_binding	nfsd_nlm_ops = {
 	.fopen		= nlm_fopen,		/* open file for locking */
 	.fclose		= nlm_fclose,		/* close file */
 };
diff -puN fs/nfsd/nfsfh.c~nfsd--global-static-cleanups-for-nfsd fs/nfsd/nfsfh.c
--- 25/fs/nfsd/nfsfh.c~nfsd--global-static-cleanups-for-nfsd	2005-02-07 19:19:14.000000000 -0800
+++ 25-akpm/fs/nfsd/nfsfh.c	2005-02-07 19:19:14.000000000 -0800
@@ -41,7 +41,7 @@ extern struct export_operations export_o
  * if not, require that we can walk up to exp->ex_dentry
  * doing some checks on the 'x' bits
  */
-int nfsd_acceptable(void *expv, struct dentry *dentry)
+static int nfsd_acceptable(void *expv, struct dentry *dentry)
 {
 	struct svc_export *exp = expv;
 	int rv;
@@ -280,8 +280,8 @@ out:
  * an inode.  In this case a call to fh_update should be made
  * before the fh goes out on the wire ...
  */
-inline int _fh_update(struct dentry *dentry, struct svc_export *exp,
-		      __u32 *datap, int *maxsize)
+static inline int _fh_update(struct dentry *dentry, struct svc_export *exp,
+			     __u32 *datap, int *maxsize)
 {
 	struct export_operations *nop = exp->ex_mnt->mnt_sb->s_export_op;
 	
@@ -297,8 +297,9 @@ inline int _fh_update(struct dentry *den
 /*
  * for composing old style file handles
  */
-inline void _fh_update_old(struct dentry *dentry, struct svc_export *exp,
-			   struct knfsd_fh *fh)
+static inline void _fh_update_old(struct dentry *dentry,
+				  struct svc_export *exp,
+				  struct knfsd_fh *fh)
 {
 	fh->ofh_ino = ino_t_to_u32(dentry->d_inode->i_ino);
 	fh->ofh_generation = dentry->d_inode->i_generation;
diff -puN fs/nfsd/nfssvc.c~nfsd--global-static-cleanups-for-nfsd fs/nfsd/nfssvc.c
--- 25/fs/nfsd/nfssvc.c~nfsd--global-static-cleanups-for-nfsd	2005-02-07 19:19:14.000000000 -0800
+++ 25-akpm/fs/nfsd/nfssvc.c	2005-02-07 19:19:14.000000000 -0800
@@ -60,7 +60,7 @@ struct nfsd_list {
 	struct list_head 	list;
 	struct task_struct	*task;
 };
-struct list_head nfsd_list = LIST_HEAD_INIT(nfsd_list);
+static struct list_head nfsd_list = LIST_HEAD_INIT(nfsd_list);
 
 /*
  * Maximum number of nfsd processes
diff -puN fs/nfsd/vfs.c~nfsd--global-static-cleanups-for-nfsd fs/nfsd/vfs.c
--- 25/fs/nfsd/vfs.c~nfsd--global-static-cleanups-for-nfsd	2005-02-07 19:19:14.000000000 -0800
+++ 25-akpm/fs/nfsd/vfs.c	2005-02-07 19:19:14.000000000 -0800
@@ -707,8 +707,8 @@ nfsd_close(struct file *filp)
  * As this calls fsync (not fdatasync) there is no need for a write_inode
  * after it.
  */
-inline void nfsd_dosync(struct file *filp, struct dentry *dp, 
-			struct file_operations *fop)
+static inline void nfsd_dosync(struct file *filp, struct dentry *dp,
+			       struct file_operations *fop)
 {
 	struct inode *inode = dp->d_inode;
 	int (*fsync) (struct file *, struct dentry *, int);
@@ -720,7 +720,7 @@ inline void nfsd_dosync(struct file *fil
 }
 	
 
-void
+static void
 nfsd_sync(struct file *filp)
 {
 	struct inode *inode = filp->f_dentry->d_inode;
@@ -730,7 +730,7 @@ nfsd_sync(struct file *filp)
 	up(&inode->i_sem);
 }
 
-void
+static void
 nfsd_sync_dir(struct dentry *dp)
 {
 	nfsd_dosync(NULL, dp, dp->d_inode->i_fop);
_
